sdv.tabular.copulas.GaussianCopula
==================================

.. currentmodule:: sdv.tabular.copulas

.. autoclass:: GaussianCopula

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GaussianCopula.__init__
      ~GaussianCopula.fit
      ~GaussianCopula.get_distributions
      ~GaussianCopula.get_likelihood
      ~GaussianCopula.get_metadata
      ~GaussianCopula.get_parameters
      ~GaussianCopula.load
      ~GaussianCopula.sample
      ~GaussianCopula.sample_conditions
      ~GaussianCopula.sample_remaining_columns
      ~GaussianCopula.save
      ~GaussianCopula.set_parameters
   
   

   
   
   